use galactica_content::{AnimAutomaton, AnimationState, Content, FactionHandle, Projectile};
use rand::Rng;
use rapier2d::{dynamics::RigidBodyHandle, geometry::ColliderHandle};

/// A single projectile in this simulation
#[derive(Debug, Clone)]
pub struct PhysProjectile {
	/// This projectile's game data
	pub content: Projectile,

	/// This projectile's sprite animation state
	anim: AnimAutomaton,

	/// The remaining lifetime of this projectile, in seconds
	pub lifetime: f32,

	/// The faction this projectile belongs to
	pub faction: FactionHandle,

	/// This projectile's rigidbody
	pub rigid_body: RigidBodyHandle,

	/// This projectile's collider
	pub collider: ColliderHandle,

	/// This projectile's size variation
	pub size_rng: f32,
}

impl PhysProjectile {
	/// Create a new projectile
	pub fn new(
		ct: &Content,
		content: Projectile, // TODO: use a handle?
		rigid_body: RigidBodyHandle,
		faction: FactionHandle,
		collider: ColliderHandle,
	) -> Self {
		let mut rng = rand::thread_rng();
		let size_rng = content.size_rng;
		let lifetime = content.lifetime;
		PhysProjectile {
			anim: AnimAutomaton::new(ct, content.sprite),
			rigid_body,
			collider,
			content,
			lifetime,
			faction,
			size_rng: rng.gen_range(-size_rng..=size_rng),
		}
	}

	/// Process this projectile's state after `t` seconds
	pub fn tick(&mut self, ct: &Content, t: f32) {
		self.lifetime -= t;
		self.anim.step(ct, t)
	}

	/// Has this projectile expired?
	pub fn is_expired(&self) -> bool {
		return self.lifetime < 0.0;
	}
}

impl PhysProjectile {
	/// Get this projectile's animation state
	pub fn get_anim_state(&self) -> AnimationState {
		self.anim.get_texture_idx()
	}
}
